@@ -263,14 +263,20 @@ void Atom::Update ()
 	}
 	int nbonds = GetTotalBondsNumber ();
 	if (m_Valence > 0 && !m_Element->IsMetallic ()) {
-		m_nlp = (m_Element->GetValenceElectrons () - m_Valence) / 2;
+		m_nlp = (m_Element->GetValenceElectrons () - ((nbonds > m_Valence)? nbonds: m_Valence)) / 2;
 		if ((m_Charge > 0) && (m_nlp > 0)) m_nlp -= (m_Charge + 1) / 2;
 		else if (m_Charge < 0)
 			m_nlp -= m_Charge;
 		if (m_nlp < nexplp) // Can this occur ?
 			m_nlp = nexplp;
-		else if (m_nlp > m_ValenceOrbitals - nbonds - nexplu)
-			m_nlp = m_ValenceOrbitals - nbonds - nexplu;
+		else if (m_nlp > m_ValenceOrbitals - nbonds - nexplu) {
+			int max_bonds = Element::GetElement (m_Z)->GetMaxBonds ();
+			if (max_bonds > m_ValenceOrbitals) {
+				if (m_nlp > max_bonds - nbonds - nexplu)
+					m_nlp = max_bonds - nbonds - nexplu;// FIXME, might be wrong, but will this occur?
+			} else
+				m_nlp = m_ValenceOrbitals - nbonds - nexplu;
+		}
 		if (m_nlp < 0)
 			m_nlp = 0;
 		nb = m_Element->GetValenceElectrons () - 2 * m_nlp - m_Charge;
@@ -431,6 +437,8 @@ gccv::Anchor Atom::GetChargePosition (unsigned char& Pos, double Angle, double&
 	double angle;
 	if (m_ChargePos != 0xff)
 		m_OccupiedPos &= ~m_ChargePos;
+	if (m_ChargeAutoPos) // reset the charge position
+		m_ChargePos = 0xff;
 	if (!m_AvailPosCached)
 		UpdateAvailablePositions ();
 	if (m_ChargePos != 0xff)
@@ -843,18 +851,9 @@ void Atom::NotifyPositionOccupation (unsigned char pos, bool occupied)
 	
 xmlNodePtr Atom::Save (xmlDocPtr xml) const
 {
-	xmlNodePtr node = gcu::Atom::Save (xml), child;
-	if (node) {
-	// Save electrons
-		map<string, Object*>::const_iterator i;
-		Electron* electron = (Electron*) GetFirstChild (i);
-		while (electron){ 
-			child = electron->Save (xml);
-			if (child)
-				xmlAddChild (node, child);
-			electron = (Electron*) GetNextChild (i);
-		}
-	}
+	xmlNodePtr node = gcu::Atom::Save (xml);
+	if (node)
+		SaveChildren (xml, node);
 	if (m_Charge && !m_ChargeAutoPos) {
 		char *buf;
 		if (m_ChargePos) {
