@@ -4,7 +4,7 @@
  * GChemPaint library
  * fragment-atom.h 
  *
- * Copyright (C) 2003-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2003-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -32,6 +32,7 @@
 namespace gcp {
 
 class Fragment;
+class View;
 
 /*!\class FragmentAtom gcp/fragment-atom.h
 Represents an atom inside a atoms group (see gcp::Fragment class).
@@ -71,29 +72,24 @@ no multiple bond at all.
 */
 	bool AcceptNewBonds (int nb);
 /*!
-@param w a GtkWidget.
-
-Overrided to avoid Atom::Add execution. Don't do anything.
-*/
-	void Add (GtkWidget* w) const;
-/*!
 Overrided to avoid Atom::Update execution. Just call Fragment::Update() method.
 */
 	void Update ();
 /*!
-@param w a GtkWidget.
-
-Overrided to avoid Atom::Update execution. Just call Fragment::Update(w).
+Overrided to avoid Atom::AddItem execution. Don't do anything.
 */
-	void Update (GtkWidget* w) const;
+	void AddItem ();
+/*!
+Overrided to avoid Atom::UpdateItem execution. Just call Fragment::UpdateItem().
+*/
+	void UpdateItem ();
 /*!
-@param w the GtkWidget inside which the atom is displayed.
 @param state the selection state of the atom.
 
 Overrided to avoid Atom::SetSelected execution. Just call Fragment::SetSelected
 method.
 */
-	void SetSelected (GtkWidget* w, int state);
+	void SetSelected (int state);
 /*!
 @param xml the xmlDoc used to save the document.
 
@@ -118,15 +114,10 @@ already exist.
 On input \a Pos can be one of POSITION_E, POSITION_N,... or 0xff, in which case,
 it will be given a default value. \a x and \a y are set to the position where the charge
 sign should be displayed usding the alignment code returned by this method.
-@return a number to set how the charge symbol should be aligned relative to its
-position. Possible values are:
-- −2: center top.
-- −1: right.
--  0: center.
--  1: left.
--  2: center bottom.
+@return the anchor for the charge symbol. On error, gccv::AnchorCenter is used as
+the returned value.
 */
-	int GetChargePosition (unsigned char& Pos, double Angle, double& x, double& y);
+	gccv::Anchor GetChargePosition (unsigned char& Pos, double Angle, double& x, double& y);
 /*!
 @param x the x position.
 @param y the y position.
@@ -179,6 +170,9 @@ Builds the symbol geometry if necessary.
 */
 	void DoBuildSymbolGeometry (View *pView);
 
+/*!\fn GetFragment()
+@return the Fragment enclosing the FragmentAtom.
+*/
 GCU_RO_POINTER_PROP (Fragment, Fragment)
 };
 
