@@ -4,7 +4,7 @@
  * GChemPaint library
  * text.cc 
  *
- * Copyright (C) 2002-2009 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -893,6 +893,11 @@ bool Text::OnChanged (bool save)
 		Tool* TextTool = dynamic_cast<Application*> (pDoc->GetApplication ())->GetTool ("Text");
 		if (!TextTool)
 			return  true;
+		if (m_TextItem) {
+			unsigned start, pos;
+			m_TextItem->GetSelectionBounds (start, pos);
+			SelectionChanged (start, pos);
+		}
 		xmlNodePtr node = SaveSelected ();
 		if (node)
 			TextTool->PushNode (node);
@@ -1003,4 +1008,9 @@ void Text::JustificationChanged (GtkJustification justification)
 	OnChanged (!m_bLoading);
 }
 
+std::string Text::Name ()
+{
+	return _("Text");
+}
+
 }	//	namespace gcp
