@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * programs/gchemtable-curve.cc 
  *
- * Copyright (C) 2005-2009 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -35,11 +35,13 @@
 #include <glib/gi18n.h>
 #include <map>
 #include <cstring>
+#include <sstream>
 
 using namespace gcu;
 using namespace std;
 
 map<string, GChemTableCurve*> curves;
+GObject *Copied;
 
 void on_show_curve (GObject *obj, char const* name)
 {
@@ -76,9 +78,13 @@ static void on_get_data (G_GNUC_UNUSED GtkClipboard *clipboard, GtkSelectionData
 			go_setlocale (LC_MONETARY, "C");
 			go_locale_untranslated_booleans ();
 		
+			GogObject *graph_;
+			graph_ = gog_object_dup (GOG_OBJECT (graph),
+				NULL, gog_dataset_dup_to_simple);
 			xout = gsf_xml_out_new (output);
-			gog_object_write_xml_sax (GOG_OBJECT (graph), xout, NULL);
+			gog_object_write_xml_sax (GOG_OBJECT (graph_), xout, NULL);
 			g_object_unref (xout);
+			g_object_unref (graph_);
 		
 			/* go_setlocale restores bools to locale translation */
 			go_setlocale (LC_MONETARY, old_monetary_locale);
@@ -116,6 +122,7 @@ static void on_get_data (G_GNUC_UNUSED GtkClipboard *clipboard, GtkSelectionData
 
 void on_clear_data(G_GNUC_UNUSED GtkClipboard *clipboard, GogGraph *graph)
 {
+	Copied = NULL;
 	g_object_unref (graph);
 }
 
@@ -263,7 +270,7 @@ static const char *ui_description =
 "</ui>";
 
 GChemTableCurve::GChemTableCurve (GChemTableApp *App, char const *name):
-	Dialog (App, UIDIR"/curve.ui", "curvedlg", GETTEXT_PACKAGE, App),
+	Dialog (App, UIDIR"/curve.ui", "curvedlg", GETTEXT_PACKAGE),
 	Printable (),
 	m_Guru (NULL)
 {
@@ -283,17 +290,24 @@ GChemTableCurve::GChemTableCurve (GChemTableApp *App, char const *name):
 	}
 	GtkWidget *bar = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
 	gtk_box_pack_start (GTK_BOX (m_GraphBox), bar, FALSE, FALSE, 0);
+	g_object_unref (ui_manager);
 	m_GraphWidget = go_graph_widget_new (NULL);
 	g_signal_connect_swapped (m_GraphWidget, "size-allocate", G_CALLBACK (GChemTableCurve::OnSize), this);
+	g_signal_connect_swapped (m_GraphWidget, "motion-notify-event", G_CALLBACK (GChemTableCurve::OnMotion), this);
 	gtk_widget_set_size_request (m_GraphWidget, 400, 250);
 	gtk_widget_show (m_GraphWidget);
 	gtk_box_pack_end (GTK_BOX (m_GraphBox), m_GraphWidget, TRUE, TRUE, 0);
 	m_Graph = go_graph_widget_get_graph (GO_GRAPH_WIDGET (m_GraphWidget));
 	GogChart *chart = go_graph_widget_get_chart (GO_GRAPH_WIDGET (m_GraphWidget));
 	if (!name) {
+		static unsigned id = 0;
+		char *buf = g_strdup_printf ("Custom%u\n", id++);
+		SetRealName (buf, App);
+		g_free (buf);
 		OnProperties ();
 		return;
 	}
+	SetRealName (name, App);
 	GogPlot *plot = (GogPlot *) gog_plot_new_by_name ("GogXYPlot");
 	gog_object_add_by_name (GOG_OBJECT (chart), "Plot", GOG_OBJECT (plot));
 	m_Name = name;
@@ -303,7 +317,7 @@ GChemTableCurve::GChemTableCurve (GChemTableApp *App, char const *name):
 	GOData *data, *ydata = NULL;
 	int i;
 	// FIXME: find a better way to do the following things !
-	if (!strcmp (name, "en/Pauling")) {
+	if (!strcmp (name, "en-Pauling")) {
 		ydata = gct_data_vector_get_from_name (_("Pauling electronegativity"));
 		obj = gog_object_get_child_by_role (GOG_OBJECT (chart),
 				gog_object_find_role_by_name (GOG_OBJECT (chart), "Y-Axis"));
@@ -321,7 +335,7 @@ GChemTableCurve::GChemTableCurve (GChemTableApp *App, char const *name):
 		gog_dataset_set_dim (GOG_DATASET (label), 0, data, &error);
 		gog_object_add_by_name (obj, "Label", label);
 		gtk_window_set_title (dialog, _("Electron affinity"));
-	} else if (!strncmp (name, "ei/", 3)) {
+	} else if (!strncmp (name, "ei-", 3)) {
 		unsigned rank = strtol (name + 3, NULL, 10);
 		char *rk, *buf;		
 		switch (rank) {
@@ -476,7 +490,7 @@ void GChemTableCurve::OnPageSetup ()
 void GChemTableCurve::OnCopy ()
 {
 	GtkClipboard* clipboard = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
-	g_object_ref (m_Graph);
+	Copied = G_OBJECT (g_object_ref (m_Graph));
 	gtk_clipboard_set_with_data (clipboard, targets, 4,
 		(GtkClipboardGetFunc) on_get_data, (GtkClipboardClearFunc) on_clear_data, m_Graph);
 }
@@ -551,3 +565,31 @@ void GChemTableCurve::OnSize (GChemTableCurve *curve, GtkAllocation *allocation)
 	curve->m_GraphWidth = allocation->width;
 	curve->m_GraphHeight = allocation->height;
 }
+
+bool GChemTableCurve::OnMotion (GChemTableCurve *curve, GdkEventMotion *event)
+{
+	GogRenderer *renderer = go_graph_widget_get_renderer (GO_GRAPH_WIDGET (curve->m_GraphWidget));
+	GogView *view;
+	GogObject *obj;
+	GogSeries *series;
+	int index;
+	ostringstream buf;
+	g_object_get (G_OBJECT (renderer), "view", &view, NULL);
+	gog_view_get_view_at_point (view, event->x, event->y, &obj, NULL);
+	if (!obj)
+		goto tooltip;
+	obj = gog_object_get_parent_typed (obj, GOG_TYPE_PLOT);
+	if (!obj)
+		goto tooltip;
+	view = gog_view_find_child_view (view, obj);
+	index = gog_plot_view_get_data_at_point (GOG_PLOT_VIEW (view), event->x, event->y, &series);
+	if (index >=0) {
+		buf << Element::GetElement (index + 1)->GetName ();
+		gtk_widget_set_tooltip_text (curve->m_GraphWidget, buf.str ().c_str ());
+		return true;
+	}
+
+tooltip:
+	gtk_widget_set_tooltip_text (curve->m_GraphWidget, NULL);
+	return true;
+}
